@@ -1,7 +1,7 @@
 # -*- encoding:utf-8 -*-
-from flask import Module
+from flask import Blueprint
 
-frontend = Module(__name__)
+frontend = Blueprint('frontend',__name__)
 
 @frontend.route('/')
 def index():
