@@ -79,14 +79,14 @@ def run_appengine_server(app):
     return action
 
 def run_gunicorn_server(app):
-    def action(bind=('b','127.0.0.1:8000'),workers=('w',4),pid=('p','tmp/flask.pid')):
+    def action(bind=('b','127.0.0.1:8000'),workers=('w',4),pid=('p','tmp/flask.pid'),log_file='tmp/flask.log',log_level='info'):
         """run application use gunicorn http server
         """
         from gunicorn import version_info
         if version_info < (0, 9, 0):
             from gunicorn.arbiter import Arbiter
             from gunicorn.config import Config
-            arbiter = Arbiter(Config({'bind':bind,'workers': 4}), app)
+            arbiter = Arbiter(Config({'bind':bind,'workers': workers,'pidfile':pidfile,'logfile':logfile}), app)
             arbiter.run()
         else:
             from gunicorn.app.base import Application
@@ -97,6 +97,8 @@ def run_gunicorn_server(app):
                         'bind': bind,
                         'workers': workers,
                         'pidfile':pid,
+                        'logfile':log_file,
+                        'loglevel':log_level,
                     }
                 
                 def load(self):
